@@ -17,5 +17,12 @@ def get_profile(user):
 
 
 def get_my_profile_module_name():
+    """ Figures out the name of the profile model name from the AUTH_PROFILE_MODULE setting
+    
+        Examples:
+        
+            my_profile = profiles.Profile
+            my_membership = members.Membership
+    """
     my_profile_module_name = settings.AUTH_PROFILE_MODULE.split('.')[-1].lower()
     return "my_{0}".format(my_profile_module_name)
